﻿<?php
class Chronopay extends PaymentModule
{
	private	$_html = '';
	private $_postErrors = array();
	private $_responseReasonText = null;

	public function __construct()
	{
		$this->name = 'chronopay';
		if((str_replace(".","",substr(_PS_VERSION_,0,3))*1)>13) $this->tab = 'payments_gateways';
		else $this->tab = 'Payment';
		$this->version = substr(_PS_VERSION_,0,3);

        parent::__construct();

        /* The parent construct is required for translations */
		$this->page = basename(__FILE__, '.php');
        $this->displayName = $this->l('Chronopay');
        $this->description = $this->l('Chronopay Hosted Payment');
	}

	

	public function install()
	{
		if (!parent::install() OR
			!Configuration::updateValue('CHRONOPAY_PROD_ID', 'your-chronopay-product-id') OR
			!Configuration::updateValue('CHRONOPAY_SHAREDSEC', 'Chronopay-Shared-Secret-Key') OR
			!$this->registerHook('payment'))
			return false;
		return true;
	}

	public function uninstall()
	{
		if (!Configuration::deleteByName('CHRONOPAY_PROD_ID') OR
			!Configuration::deleteByName('CHRONOPAY_SHAREDSEC') OR
			!parent::uninstall())
			return false;
		return true;
	}

	public function getContent()
	{
		$this->_html = '<h2>Chronopay</h2>';
		if (isset($_POST['submitAuthNet']))
		{
			if (empty($_POST['productID']))
				$this->_postErrors[] = $this->l('Chronopay product ID is required.');
			if (empty($_POST['sharedsec']))
				$this->_postErrors[] = $this->l('Chronopay Shared Secret Key is required.');
			
			if (!sizeof($this->_postErrors))
			{
				Configuration::updateValue('CHRONOPAY_PROD_ID', strval($_POST['productID']));
				Configuration::updateValue('CHRONOPAY_SHAREDSEC', strval($_POST['sharedsec']));
				$this->displayConf();
			}
			else
				$this->displayErrors();
		}

		$this->displayAuthNet();
		$this->displayFormSettings();
		return $this->_html;
	}

	public function displayConf()
	{
		$this->_html .= '
		<div class="conf confirm">
			<img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />
			'.$this->l('Settings updated').'
		</div>';
	}

	public function displayErrors()
	{
		$nbErrors = sizeof($this->_postErrors);
		$this->_html .= '
		<div class="alert error">
			<h3>'.($nbErrors > 1 ? $this->l('There are') : $this->l('There is')).' '.$nbErrors.' '.($nbErrors > 1 ? $this->l('errors') : $this->l('error')).'</h3>
			<ol>';
		foreach ($this->_postErrors AS $error)
			$this->_html .= '<li>'.$error.'</li>';
		$this->_html .= '
			</ol>
		</div>';
	}


	public function displayAuthNet()
	{
		$this->_html .= '
		<img src="../modules/chronopay/chronopay.jpg" style="padding: 10px 0px; margin-right:15px;" />
		<br /><br />
		<b>'.$this->l('This module allows you to accept payments by Chronopay.').'</b><br /><br />
		'.$this->l('If the client chooses this payment mode, your Chronopay account will be automatically credited.').'<br />
		'.$this->l('You need to configure your Chronopay account first before using this module.').'
		<br /><br /><br />';
	}

	public function displayFormSettings()
	{
		$conf = Configuration::getMultiple(array('CHRONOPAY_PROD_ID',
												'CHRONOPAY_SHAREDSEC',
												));
		
		$productID = array_key_exists('productID', $_POST) ? $_POST['productID'] : (array_key_exists('CHRONOPAY_PROD_ID', $conf) ? $conf['CHRONOPAY_PROD_ID'] : '');
		$sharedsec = array_key_exists('sharedsec', $_POST) ? $_POST['sharedsec'] : (array_key_exists('CHRONOPAY_SHAREDSEC', $conf) ? $conf['CHRONOPAY_SHAREDSEC'] : 'prestashop');

		$this->_html .= '
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
		<fieldset>
			<legend><img src="../img/admin/contact.gif" />'.$this->l('Settings').'</legend>
			
			<label>'.$this->l('Product ID').'</label>
			<div class="margin-form"><input type="text" size="38" name="productID" value="'.htmlentities($productID, ENT_COMPAT, 'UTF-8').'" /></div>
			
			<label>'.$this->l('Shared Secret Key').'</label>
			<div class="margin-form"><input type="password" size="38" name="sharedsec" value="'.htmlentities($sharedsec, ENT_COMPAT, 'UTF-8').'" /></div>
			
			<br /><center><input type="submit" name="submitAuthNet" value="'.$this->l('Update settings').'" class="button" /></center>
		</fieldset>
		</form><br /><br />
		<fieldset class="width3">
			<legend><img src="../img/admin/warning.gif" />'.$this->l('Information').'</legend>
			'.$this->l('This module use "Control of order uniqueness" feature of Chronopay. Please, before you starting to use this module, ask Chronopay Integration to turn ON "order_id" parameter for your Client ID. 
				Please, send emails to: integration@chronopay.com').'<br /><br />



			'.$this->l('Этот модуль использует опциональную возможность Хронопэй "Контроль уникальности заказа". Пожалуйста, перед началом использования модуля попросите отдел Интеграции Хронопэй включить на Вашем Client ID параметр "order_id". 
				Адрес email отдела Интеграции Хронопэй: integration@chronopay.com').'<br /><br />


			'.'
		</fieldset>';
	}

	public function hookPayment($params)
	{
		global $smarty;

		$smarty->assign(array(
            'this_path' => $this->_path,
            'this_path_ssl' => (Configuration::get('PS_SSL_ENABLED') ? 'https://' : 'http://').htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8').__PS_BASE_URI__.'modules/'.$this->name.'/'
        ));

        return $this->display(__FILE__, 'chronopay.tpl');
    }

	
    public function populatePaymentVars()
    {
		global $smarty, $cart, $cookie;

		$address = new Address(intval($cart->id_address_invoice));
		$customer = new Customer(intval($cookie->id_customer));
		$country = new Country(intval($cookie->id_customer));
		$productID = Configuration::get('CHRONOPAY_PROD_ID');
		$sharedsec = Configuration::get('CHRONOPAY_SHAREDSEC');
		$price = $cart->getOrderTotal(true, 3);
		$orderId = $cart->id;
		$sign = md5($productID."-".$price."-".$orderId."-".$sharedsec);
		$state = new State(intval($address->id_state));
		
		
		
		$smarty->assign(array(
			'product_id' => $productID,
			'price' => $price,
			'sign' => $sign,
			'cb_url' => (Configuration::get('PS_SSL_ENABLED') ? 'https://' : 'http://').htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8').__PS_BASE_URI__.'modules/chronopay/response.php',
			'success_url' => (Configuration::get('PS_SSL_ENABLED') ? 'https://' : 'http://').htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8').__PS_BASE_URI__.'modules/chronopay/thank-you.php',
			'decline_url' => (Configuration::get('PS_SSL_ENABLED') ? 'https://' : 'http://').htmlspecialchars($_SERVER['HTTP_HOST'], ENT_COMPAT, 'UTF-8').__PS_BASE_URI__.'index.php?controller=order',
			'f_name' => $customer->firstname,
			's_name' => $customer->lastname,
			'country' => $country->iso_code,
			'state' => $state->iso_code,
			'zip' => $address->postcode,
			'phone' => $address->phone,
			'city' => $address->city,
			'street' => $address->address1.",".$address->address2,
			'email' => $customer->email,
			'order_id' => $orderId,
		));
    }

	
   
    public function getResponseReasonText()
    {
		return $this->_responseReasonText;
	}


}

?>
